
Developing cx_Freeze
====================

The source code can be found `on Github <https://github.com/anthony-tuininga/cx_Freeze>`__.

Issue tracking `on Github <https://github.com/anthony-tuininga/cx_Freeze/issues>`__.

Install by issuing the command::

    python -m pip install cx_Freeze --upgrade

or download directly from `PyPI <https://pypi.python.org/pypi/cx_Freeze>`_.

Contents:

.. toctree::
   :maxdepth: 2
   
   code_layout.rst
